@@ -601,7 +601,7 @@ class BaseProject:
             if len(self.dims) == 2 : # 2D, black & white
                 imgs = np.reshape(self.X, (-1, 1, *self.dims)) # (# of samples, # of channels, height, width) i.e., NCHW   
             elif len(self.dims) > 2 : # 2D, colored images
-                dims = rearrange_dims(dims=self.dims, dataformats=dataformats)
+                dims = rearrange_dims(dims=self.dims, in_format=dataformats, dataformats="NCHW")
                 imgs = np.reshape(self.X, (-1, *dims)) # (# of samples, # of channels, height, width) i.e., NCHW
 
 
@@ -627,7 +627,9 @@ class BaseProject:
                     idx += 1
                     if idx < n_data + 1:
                         img = fig.add_subplot(rows, cols, idx)
-                        img.imshow(self.X[sampling_idx][idx-1])
+                        if len(self.dims) > 2:
+                            dims_imshow = rearrange_dims(self.dims, in_format=dataformats, dataformats="NHWC")
+                        img.imshow(self.X[sampling_idx][idx-1].reshape(dims_imshow))
                         img.set_title(f'label : {labels_to_show[idx-1]}')
             plt.show()
             plt.savefig(f"{img_dir}/image_samples.png")       
