@@ -10,6 +10,7 @@ from torchmetrics import AUROC
 from torchmetrics.functional import dice_score
 from typing import Union, List, Dict, Any, Optional, Tuple
 from torch.nn import functional as F
+from itertools import permutations
 
 def column_or_1d(y):
     y = torch.as_tensor(y)
@@ -303,7 +304,21 @@ def divide_set(X, y, column, value):
 
     return X_set_1, y_set_1, X_set_2, y_set_2
 
-def rearrange_dims(dims, dataformats="NCHW"):
+def rearrange_dims(dims, in_format, dataformats="NCHW"):
+    def find_mapping(in_format, dataformats):
+        mappings = list(permutations([0,1,2]))
+        c_to_i = {"N" : 0, "C" : 1, "H" : 2, "W" : 3}
+        in_format_array = np.array([])
+        dataformat_array = np.array([])
+        for c_in, c_out in zip(in_format, dataformats):
+            in_format_array = np.concatenate([in_format_array, np.array([c_to_i[c_in]])]).astype(int)
+            dataformat_array = np.concatenate([dataformat_array, np.array([c_to_i[c_out]])]).astype(int)
+        for mapping in mappings:
+            mapped = np.transpose(in_format_array, mapping)
+            if mapped == dataformat_array:
+                break
+        return mapping
+
     if isinstance(dims, int):
             raise ValueError(f"Wrong dimension {dims} for an input.")
     elif len(dims) == 2:
@@ -311,25 +326,10 @@ def rearrange_dims(dims, dataformats="NCHW"):
         width = dims[1]
         dims = (1, height, width)
     elif len(dims) == 3:
-        if dataformats == "NCHW":
-            dims = dims
-        elif dataformats == "NHCW":
-            height, channels, width = dims
-            dims = (channels, height, width)
-        elif dataformats == "NHWC":
-            height, width, channels = dims
-            dims = (channels, height, width)
-        elif dataformats == "NCWH":
-            channels, width, height = dims
-            dims = (channels, height, width)
-        elif dataformats == "NWHC":
-            width, height, channels = dims
-            dims = (channels, height, width)
-        elif dataformats == "NWCH":
-            width, channels, height = dims
-            dims = (channels, height, width)
-        else:
-            raise ValueError(f"Invalid dataformats {dataformats}. It should start with 'N' followed by permutation of 'HWC'.")
+        temp = np.array(dims)
+        mapping = find_mapping(in_format, dataformats)
+        dims = tuple(np.transpose(temp, mapping))
+        
     else:
         raise ValueError(f"Wrong dimension {dims} for an input.")
     return dims
